ListChangeNotification<E> class

A record of change in a RxList

Constructors

ListChangeNotification(E? element, ListChangeOp op, int? pos, {DateTime? time})
ListChangeNotification.clear({DateTime? time})
ListChangeNotification.insert(E? element, int? pos, {DateTime? time})
ListChangeNotification.remove(E? element, int? pos, {DateTime? time})
ListChangeNotification.set(E? element, int? pos, {DateTime? time})

Properties

element → E?
final
hashCode → int
The hash code for this object.
no setterinherited
op → ListChangeOp
final
pos → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited