SetChangeNotification<E> class

Constructors

SetChangeNotification(E element, SetChangeOp op, {DateTime? time})
SetChangeNotification.add(E element, {DateTime? time})
SetChangeNotification.remove(E element, {DateTime? time})

Properties

element → E
final
hashCode → int
The hash code for this object.
no setterinherited
op → SetChangeOp
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited